# WSKNN: k-NN recommender for session-based data

## Weighted session-based k-NN - Intro

...

### When?

...

### Why?

...

### Example

...

## Setup

...

## Requirements

| Package Version | Python versions | Other packages |
|-----------------|-----------------|----------------|
| 0.1 | 3.6+ | numpy, yaml |


## Developers

- Szymon Moliński (Sales Intelligence : Digitree Group SA)

## Bibliography

- Twardowski, B., Zawistowski, P., Zaborowski, S. (2021). Metric Learning for Session-Based Recommendations. In: Hiemstra, D., Moens, MF., Mothe, J., Perego, R., Potthast, M., Sebastiani, F. (eds) Advances in Information Retrieval. ECIR 2021. Lecture Notes in Computer Science(), vol 12656. Springer, Cham. https://doi.org/10.1007/978-3-030-72113-8_43

## Funding

![Funding](./eu_funding_logos/FE_POIR_poziom_engl-1_rgb.jpg)

- Development of the package was partially based on the research project
**E-commerce Shopping Patterns Prediction System** that 
was funded under Priority Axis 1.1 of Smart Growth Operational Programme 2014-2020 for Poland
co-funded by European Regional Development Fund. Project number: `POIR.01.01.01-00-0632/18`